summaryrefslogtreecommitdiffhomepage
path: root/src/raylib.h
diff options
context:
space:
mode:
authorRay <[email protected]>2022-12-07 12:52:42 +0100
committerRay <[email protected]>2022-12-07 12:52:42 +0100
commit2c9d116a5ce835328dc3267313f1b34b2e7ad8c9 (patch)
tree0168cc6468f85b8b0903fd7d5b8ac0b12c2ac6b4 /src/raylib.h
parentf1368c36dd38dd912782485ce827fb8b35b86365 (diff)
downloadraylib-2c9d116a5ce835328dc3267313f1b34b2e7ad8c9.tar.gz
raylib-2c9d116a5ce835328dc3267313f1b34b2e7ad8c9.zip
ADDED: `ColorTint()`, `ColorContrast()`
Diffstat (limited to 'src/raylib.h')
-rw-r--r--src/raylib.h4
1 files changed, 3 insertions, 1 deletions
diff --git a/src/raylib.h b/src/raylib.h
index 6642bc8d..dc71af84 100644
--- a/src/raylib.h
+++ b/src/raylib.h
@@ -1331,7 +1331,9 @@ RLAPI Vector4 ColorNormalize(Color color); // G
RLAPI Color ColorFromNormalized(Vector4 normalized); // Get Color from normalized values [0..1]
RLAPI Vector3 ColorToHSV(Color color); // Get HSV values for a Color, hue [0..360], saturation/value [0..1]
RLAPI Color ColorFromHSV(float hue, float saturation, float value); // Get a Color from HSV values, hue [0..360], saturation/value [0..1]
-RLAPI Color ColorBrightness(Color color, float factor); // Get color with brightness correction, brightness factor goes from 0.0f to 1.0f
+RLAPI Color ColorTint(Color color, Color tint); // Get color multiplied with another color
+RLAPI Color ColorBrightness(Color color, float factor); // Get color with brightness correction, brightness factor goes from -1.0f to 1.0f
+RLAPI Color ColorContrast(Color color, float contrast); // Get color with contrast correction, contrast values between -1.0f and 1.0f
RLAPI Color ColorAlpha(Color color, float alpha); // Get color with alpha applied, alpha goes from 0.0f to 1.0f
RLAPI Color ColorAlphaBlend(Color dst, Color src, Color tint); // Get src alpha-blended into dst color with tint
RLAPI Color GetColor(unsigned int hexValue); // Get Color structure from hexadecimal value